%global apiversion 0.12
%define major 0

%define libname %mklibname orcus %{apiversion} %{major}
%define develname %mklibname -d orcus

# libixion isn't available on armv5:
%ifarch armv5tl
%bcond_with convtools
%else
# build conversion tools
%bcond_without convtools
%endif
# build python3 bindings
%bcond_without python

Name: liborcus
Version: 0.12.1
Release: %mkrel 2
Summary: Standalone file import filter library for spreadsheet documents
Group: Office/Spreadsheet
License: MPLv2.0
URL: https://gitlab.com/orcus/orcus
Source0: http://kohei.us/files/orcus/src/%{name}-%{version}.tar.xz
BuildRequires: boost-devel
BuildRequires: doxygen
%if %{with convtools}
BuildRequires: help2man
BuildRequires: pkgconfig(libixion-0.12)
%endif
BuildRequires: pkgconfig(mdds-1.2)
%if %{with python}
BuildRequires: pkgconfig(python3)
%endif
BuildRequires: pkgconfig(zlib)

# (tv) fix underlinking:
Patch100: fix-underlinking.diff

%description
%{name} is a standalone file import filter library for spreadsheet
documents. Currently under development are ODS, XLSX and CSV import
filters.

%if %{with convtools}
%package model
Summary: Spreadsheet model for %{name} conversion tools

%description model
The %{name}-model package contains a spreadsheet model used by the
conversion tools.
%endif

%package -n %{libname}
Summary: Standalone file import filter library for spreadsheet documents
Group: Office/Spreadsheet
Obsoletes: %{name} < %{version}-%{release}
# Temporary for cauldron:
Obsoletes: liborcus0.4 %{mklibname orcus 0.4 %major}

%description -n %{libname}
%{name} is a standalone file import filter library for spreadsheet
documents. Currently under development are ODS, XLSX and CSV import
filters.

%package -n %{develname}
Summary: Development files for %{name}
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Obsoletes: %{name}-devel < %{version}-%{release}
# Temporary for cauldron:
Obsoletes: %{_lib}orcus0.4-devel
Obsoletes: %{name}-doc < 0.12.1-2

%description -n %{develname}
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package tools
Summary: Tools for working with Orcus
Group: Office/Spreadsheet
Requires: %{libname} = %{version}-%{release}
# Temporary for cauldron:
Obsoletes: liborcus0.4-tools

%description tools
Helper tools for %{name} and converters of various file formats to HTML
and text.

%if %{with python}
%package python3
Summary: Python 3 bindings for %{name}

%description python3
Python 3 bindings for %{name}.
%endif

#package doc
#Summary: API documentation for %%{name}
#BuildArch: noarch

#description doc
#API documentation for %%{name}.

%prep
%autosetup -p1

%if %{without convtools}
%global condopts %{?condopts} --disable-spreadsheet-model
%endif
%if %{without python}
%global condopts %{?condopts} --disable-python
%endif

%build
%configure2_5x --disable-debug --disable-silent-rules --disable-static \
    --disable-werror --with-pic %{?condopts}
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make

%install
%makeinstall_std
rm -f %{buildroot}%{_libdir}/*.la %{buildroot}%{python3_sitearch}/*.la

%if %{with convtools}
# create and install man pages
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -N -S '%{name} %{version}' -n 'convert a CSV file' -o orcus-csv.1 %{buildroot}/usr/bin/orcus-csv
help2man -N -S '%{name} %{version}' -n 'convert a Gnumeric file' -o orcus-gnumeric.1 %{buildroot}/usr/bin/orcus-gnumeric
help2man -N -S '%{name} %{version}' -n 'convert an ODF spreadsheet' -o orcus-ods.1 %{buildroot}/usr/bin/orcus-ods
help2man -N -S '%{name} %{version}' -n 'transform an XML file' -o orcus-xls-xml.1 %{buildroot}/usr/bin/orcus-xls-xml
help2man -N -S '%{name} %{version}' -n 'convert a OpenXML spreadsheet' -o orcus-xlsx.1 %{buildroot}/usr/bin/orcus-xlsx
help2man -N -S '%{name} %{version}' -n 'convert an XML file' -o orcus-xml.1 %{buildroot}/usr/bin/orcus-xml
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -p -m 0644 orcus-*.1 %{buildroot}/%{_mandir}/man1
%endif
 
# build documentation
# make doc-doxygen

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
%make check

%files -n %{libname}
%doc AUTHORS
%license LICENSE
%{_libdir}/%{name}*-%{apiversion}.so.%{major}{,.*}


%files -n %{develname}
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}*-%{apiversion}.so
%{_libdir}/pkgconfig/*.pc

%files tools
%{_bindir}/orcus-css-dump
%{_bindir}/orcus-detect
%{_bindir}/orcus-json
%{_bindir}/orcus-mso-encryption
%{_bindir}/orcus-xml-dump
%{_bindir}/orcus-zip-dump
%{_bindir}/orcus-yaml
%if %{with convtools}
%{_bindir}/orcus-csv
%{_bindir}/orcus-gnumeric
%{_bindir}/orcus-ods
%{_bindir}/orcus-xls-xml
%{_bindir}/orcus-xlsx
%{_bindir}/orcus-xml
%{_mandir}/man1/orcus-csv.1*
%{_mandir}/man1/orcus-gnumeric.1*
%{_mandir}/man1/orcus-ods.1*
%{_mandir}/man1/orcus-xls-xml.1*
%{_mandir}/man1/orcus-xlsx.1*
%{_mandir}/man1/orcus-xml.1*
%endif

%if %{with python}
%files python3
%{python3_sitearch}/_orcus.so
%{python3_sitearch}/_orcus_json.so
%{python3_sitelib}/orcus/__pycache__/
%{python3_sitelib}/orcus/__init__.py
%{python3_sitelib}/orcus/json.py
%{python3_sitelib}/orcus/xlsx.py
%endif

#files doc
#license LICENSE
#doc doc/_doxygen/html


%changelog
* Mon Jan 09 2017 luigiwalser <luigiwalser> 0.12.1-2.mga6
+ Revision: 1080784
- disable broken apidoc generation

* Fri Sep 30 2016 tv <tv> 0.12.1-1.mga6
+ Revision: 1057855
- new release

* Sat Sep 24 2016 tv <tv> 0.11.2-6.mga6
+ Revision: 1055651
- fix file list on armv5tl... :-(

* Fri Sep 23 2016 tv <tv> 0.11.2-5.mga6
+ Revision: 1055594
- try even harder to fix building on armv5tl

* Fri Sep 23 2016 tv <tv> 0.11.2-4.mga6
+ Revision: 1055583
- fix inverted test for armv5tl
- try harder to disable convtools on armv5tl

* Fri Sep 23 2016 tv <tv> 0.11.2-2.mga6
+ Revision: 1055573
- disable convtools on armv5tl due to missing libixion

* Mon Sep 19 2016 tv <tv> 0.11.2-1.mga6
+ Revision: 1054476
- new release
- build with new mdds & new ixion

* Mon May 09 2016 luigiwalser <luigiwalser> 0.11.1-1.mga6
+ Revision: 1011485
- 0.11.1

* Sat Mar 19 2016 luigiwalser <luigiwalser> 0.11.0-2.mga6
+ Revision: 993030
- remove invalid deps from subpackages

* Sat Mar 12 2016 tv <tv> 0.11.0-1.mga6
+ Revision: 989382
- adjust file list
- patch 100: fix underlinking
- add model subpkg
- new release
- add doc & python3 subpkgs

* Wed Mar 02 2016 tv <tv> 0.9.2-3.mga6
+ Revision: 983692
- reenable patch 1
- patch 2: fix build
- disable patch 1
- switch to new mdds and libixion

* Fri Dec 25 2015 tv <tv> 0.9.2-2.mga6
+ Revision: 914724
- rebuild for new boost 1.60

* Fri Oct 30 2015 tv <tv> 0.9.2-1.mga6
+ Revision: 896546
- new release

* Fri Sep 25 2015 tv <tv> 0.7.1-4.mga6
+ Revision: 883527
- rebuild for new boost

* Wed Aug 26 2015 tv <tv> 0.7.1-3.mga6
+ Revision: 869858
- rebuild with gcc5

* Fri Jul 31 2015 neoclust <neoclust> 0.7.1-2.mga6
+ Revision: 859844
- Rebuild against new boost

* Sun Jun 21 2015 tv <tv> 0.7.1-1.mga6
+ Revision: 837884
- new URL
- new release

* Wed Oct 15 2014 umeabot <umeabot> 0.7.0-4.mga5
+ Revision: 743631
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7.0-3.mga5
+ Revision: 681690
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 tv <tv> 0.7.0-2.mga5
+ Revision: 658706
- drop old patches
- rebuild for having a fixed package
- new release

* Sat Feb 08 2014 barjac <barjac> 0.5.1-10.mga5
+ Revision: 586669
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 0.5.1-9.mga4
+ Revision: 529281
- Mageia 4 Mass Rebuild

* Mon Jul 08 2013 fwang <fwang> 0.5.1-8.mga4
+ Revision: 451227
- rebuild for new boost

* Sat Jun 08 2013 tv <tv> 0.5.1-7.mga4
+ Revision: 440697
- fix obsoletes

* Sat Jun 08 2013 tv <tv> 0.5.1-6.mga4
+ Revision: 440661
- more obsolete for temporary liborcus0.4

* Sat Jun 08 2013 tv <tv> 0.5.1-4.mga4
+ Revision: 440632
- obsolete temporary liborcus0.4 package

* Sat May 25 2013 tv <tv> 0.5.1-2.mga4
+ Revision: 426989
- adjust file list
- bump library api
- further fix linking
- further fix linking
- patch 1: fix linking with boost
- new release
- new release

* Thu Apr 11 2013 ennael <ennael> 0.3.0-5.mga3
+ Revision: 409490
- rebuild for boost 1.53

* Sat Jan 12 2013 umeabot <umeabot> 0.3.0-4.mga3
+ Revision: 357937
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 0.3.0-3.mga3
+ Revision: 333080
- fix obsoletes

* Thu Dec 20 2012 fwang <fwang> 0.3.0-2.mga3
+ Revision: 333001
- fix missing includes
- use configure2_5x
- rebuild for new boost

* Mon Dec 17 2012 tv <tv> 0.3.0-1.mga3
+ Revision: 331976
- fix new release
- fix new release

* Mon Dec 17 2012 tv <tv> 0.1.0-1.mga3
+ Revision: 331938
- fix group
- fix group
- imported package liborcus


* Mon Dec 17 2012 Thierry Vignaud <tv@mageia.org> 0.1.0-1.mga3
- import from FC
